import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Checkbox from './Checkbox';
import CheckboxContainer, { changeType } from './CheckboxContainer';

import checkboxChange from './redux-actions/checkboxChange';
import checkboxState from './checkboxState';

import simulateLabelClick from '../../test-utils/simulateLabelClick';
import createStore from '../../test-utils/createStore';


const TestCheckbox = Checkbox({
    block: purebem.of('test-checkbox'),
    displayName: 'TestCheckbox'
});

const TestCheckboxContainer = CheckboxContainer({
    Component: TestCheckbox
});

describe('CheckboxContainer', () => {
    const path = 'condition';
    const root = 'test';
    const actionTypePrefix = 'TEST-CHECKBOX';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                condition: checkboxState()
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestCheckboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        simulateLabelClick(provider);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(checkboxChange({
            path,
            root,
            type: changeType(actionTypePrefix),
            value: true
        }));

    });

    it('should read value from store', () => {
        const store = createStore({
            test: {
                condition: checkboxState({ value: true })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestCheckboxContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const input = TestUtils.findRenderedDOMComponentWithTag(provider, 'input');
        const node = ReactDOM.findDOMNode(input);

        expect(node.checked).toBeTruthy();
    });

});
