import test from 'tape';
import Immutable from 'seamless-immutable';

import handleFoundationAction from './handleFoundationAction';


test('ignore non-relevant action', (t) => {
    const state = Immutable({ component: { value: 1 } });
    const handle = handleFoundationAction('test');
    const result = handle(state, { type: 'NON-RELEVANT-ACTION' });

    t.same(result, state);
    t.end();
});

test('ignore non-relevant foundation action', (t) => {
    const state = Immutable({ component: { obj: { value: 1 } } });
    const handle = handleFoundationAction('test');
    const result = handle(state, {
        type: 'NON-RELEVANT-ACTION',
        meta: {
            root: 'component',
            path: 'obj',
            foundation: 'non-relevant-foundation-component'
        },
        payload: {
            value: 2
        }
    });

    t.same(result, state);
    t.end();
});

test('update state for relevant action', (t) => {
    const foundation = 'test';

    const state = Immutable({ component: { obj: { value: 1 } } });
    const handle = handleFoundationAction(foundation);
    const result = handle(state, {
        type: 'RELEVANT-ACTION',
        meta: {
            root: 'component',
            path: 'obj',
            foundation
        },
        payload: {
            value: 2
        }
    });

    t.same(result, {
        component: {
            obj: {
                value: 2
            }
        }
    });

    t.end();
});
